@@ -1,8 +1,8 @@
 ###
-### R routines for the R package dlnm (c) Antonio Gasparrini 2013-2014
+### R routines for the R package dlnm (c) Antonio Gasparrini 2013-2016
 #
 thr <-
-function(x, thr.value=NULL, side=NULL, int=FALSE) {
+function(x, thr.value=NULL, side=NULL, intercept=FALSE) {
 #
 ################################################################################
 #
@@ -21,12 +21,12 @@ function(x, thr.value=NULL, side=NULL, int=FALSE) {
     h = as.matrix(pmax(x-thr.value,0)),
     l = as.matrix(-pmin(x-thr.value,0)),
     d = cbind(-pmin(x-thr.value[1],0),pmax(x-thr.value[2],0)))
-  if(int) basis <- cbind(1,basis)
+  if(intercept) basis <- cbind(1,basis)
 #
   # NAMES AND ATTRIBUTES
   dimnames(basis) <- list(nx,seq(ncol(basis)))
   attributes(basis) <- c(attributes(basis),list(thr.value=thr.value,
-    side=side,int=int))
+    side=side,intercept=intercept))
 #
   class(basis) <- c("thr","matrix")
 #
